This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] ada/*: Fix comment typos.


Hi,

Committed as obvious.

Kazu Hirata

2006-05-28  Kazu Hirata  <kazu@codesourcery.com>

	* decl.c, env.c, gigi.h, init.c, initialize.c, raise-gcc.c,
	sem_ch13.adb, sysdep.c, targtyps.c, tb-alvxw.c, tracebak.c,
	trans.c, utils.c: Fix comment typos.  Follow spelling
	conventions.
	* gnat_rm.texi, gnat_ugn.texi, : Fix typos.  Follow spelling
	conventions.

Index: ada/decl.c
===================================================================
--- ada/decl.c	(revision 114167)
+++ ada/decl.c	(working copy)
@@ -134,7 +134,7 @@ gnat_to_gnu_type (Entity_Id gnat_entity)
    DEFINITION is nonzero if this call is intended for a definition.  This is
    used for separate compilation where it necessary to know whether an
    external declaration or a definition should be created if the GCC equivalent
-   was not created previously.  The value of 1 is normally used for a non-zero
+   was not created previously.  The value of 1 is normally used for a nonzero
    DEFINITION, but a value of 2 is used in special circumstances, defined in
    the code.  */
 
@@ -4719,7 +4719,7 @@ elaborate_expression (Node_Id gnat_expr,
   if (present_gnu_tree (gnat_expr))
     return get_gnu_tree (gnat_expr);
 
-  /* If we don't need a value and this is static or a discriment, we
+  /* If we don't need a value and this is static or a discriminant, we
      don't need to do anything.  */
   else if (!need_value
 	   && (Is_OK_Static_Expression (gnat_expr)
@@ -5254,7 +5254,7 @@ gnat_to_gnu_field (Entity_Id gnat_field,
      this a bitfield and avoid making things wider.
 
      Doing this is first useful if the record is packed because we can then
-     place the field at a non-byte-aligned position and so achieve tigther
+     place the field at a non-byte-aligned position and so achieve tighter
      packing.
 
      This is in addition *required* if the field shares a byte with another
Index: ada/env.c
===================================================================
--- ada/env.c	(revision 114167)
+++ ada/env.c	(working copy)
@@ -227,7 +227,7 @@ void __gnat_unsetenv (char *name) {
      have been allocated using malloc. To avoid this memory leak another
      method can be used. It consists in forcing the reallocation of all the
      strings in the environ table using malloc on the first call on the
-     functions related to environment variable management. The disavantage
+     functions related to environment variable management. The disadvantage
      is that if a program makes a direct call to getenv the return string
      may be deallocated at some point. */
   /* Note that on AIX, unsetenv is not supported on 5.1 but it is on 5.3.
Index: ada/gnat_rm.texi
===================================================================
--- ada/gnat_rm.texi	(revision 114167)
+++ ada/gnat_rm.texi	(working copy)
@@ -7146,7 +7146,7 @@ case letters. This line is always presen
 
 @item
 @code{ppp} is the Process Id value as a decimal integer (this line is
-present only if the Process Id is non-zero). Currently we are
+present only if the Process Id is nonzero). Currently we are
 not making use of this field.
 
 @item
@@ -7456,7 +7456,7 @@ must define with the following profile:
 
    The parameter is a C null-terminated string representing a message to be
    associated with the exception (typically the source location of the raise
-   statement generated by the compiler). The Line parameter when non-zero
+   statement generated by the compiler). The Line parameter when nonzero
    represents the line number in the source program where the raise occurs.
 
 @item No_Exception_Streams
@@ -8185,7 +8185,7 @@ The ceiling priority of internal protect
 @strong{101}.  Implementation-defined queuing policies.  See D.4(1).
 @end cartouche
 @noindent
-There are no implementation-defined queueing policies.
+There are no implementation-defined queuing policies.
 
 @sp 1
 @cartouche
Index: ada/gnat_ugn.texi
===================================================================
--- ada/gnat_ugn.texi	(revision 114167)
+++ ada/gnat_ugn.texi	(working copy)
@@ -3014,7 +3014,7 @@ interface to @code{printfi}.
 @item
 It may work on some platforms to directly interface to
 a @code{varargs} function by providing a specific Ada profile
-for a a particular call. However, this does not work on
+for a particular call. However, this does not work on
 all platforms, since there is no guarantee that the
 calling sequence for a two argument normal C function
 is the same as for calling a @code{varargs} C function with
@@ -3050,7 +3050,7 @@ in section B.5 of the Ada 95 Reference M
 
 @item Intrinsic
 This applies to an intrinsic operation, as defined in the Ada 95
-Reference Manual. If a a pragma Import (Intrinsic) applies to a subprogram,
+Reference Manual. If a pragma Import (Intrinsic) applies to a subprogram,
 this means that the body of the subprogram is provided by the compiler itself,
 usually by means of an efficient code sequence, and that the user does not
 supply an explicit body for it. In an application program, the pragma can
@@ -7318,7 +7318,7 @@ Set the time slice value to @var{n} mill
 the specification of a specific time slice value, then the indicated value
 is used. If the system does not support specific time slice values, but
 does support some general notion of round-robin scheduling, then any
-non-zero value will activate round-robin scheduling.
+nonzero value will activate round-robin scheduling.
 
 A value of zero is treated specially. It turns off time
 slicing, and in addition, indicates to the tasking run time that the
@@ -9104,7 +9104,7 @@ in @ref{Inlining of Subprograms}.
 @noindent
 Although it is possible to do a reasonable amount of debugging at
 @ifclear vms
-non-zero optimization levels,
+nonzero optimization levels,
 the higher the level the more likely that
 @end ifclear
 @ifset vms
@@ -20052,7 +20052,7 @@ This command allows to switch to the tas
 particular, This allows to browse the backtrace of the specified
 task. It is advised to switch back to the original task before
 continuing execution otherwise the scheduling of the program may be
-perturbated.
+perturbed.
 @end table
 
 @noindent
Index: ada/init.c
===================================================================
--- ada/init.c	(revision 114167)
+++ ada/init.c	(working copy)
@@ -1801,7 +1801,7 @@ __gnat_init_float (void)
 #endif
 
   /* Similarly for sparc64. Achieved by masking bits in the Trap Enable Mask
-     field of the Floating-point Status Register (see the Sparc Architecture
+     field of the Floating-point Status Register (see the SPARC Architecture
      Manual Version 9, p 48).  */
 #if defined (sparc64)
 
Index: ada/initialize.c
===================================================================
--- ada/initialize.c	(revision 114167)
+++ ada/initialize.c	(working copy)
@@ -126,7 +126,7 @@ __gnat_initialize (void *eh)
      step documented for C++.  The de-registration is handled symmetrically,
      a-la C++ destructor fashion and typically triggered by the dynamic
      unloader.  Note that since the tables shall be registered against a
-     common datastructure, libgcc should be one of the modules (vs beeing
+     common datastructure, libgcc should be one of the modules (vs being
      partially linked against all the others at build time) and shall be
      loaded first.
 
Index: ada/raise-gcc.c
===================================================================
--- ada/raise-gcc.c	(revision 114167)
+++ ada/raise-gcc.c	(working copy)
@@ -62,7 +62,7 @@ typedef char bool;
    (SJLJ or DWARF). We need a consistently named interface to import from
    a-except, so wrappers are defined here.
 
-   Besides, eventhough the compiler is never setup to use the GCC propagation
+   Besides, even though the compiler is never setup to use the GCC propagation
    circuitry, it still relies on exceptions internally and part of the sources
    to handle to exceptions are shared with the run-time library.  We need
    dummy definitions for the wrappers to satisfy the linker in this case.
Index: ada/sem_ch13.adb
===================================================================
--- ada/sem_ch13.adb	(revision 114167)
+++ ada/sem_ch13.adb	(working copy)
@@ -582,7 +582,7 @@ package body Sem_Ch13 is
                   Mark_Aliased_Address_As_Volatile (Expr);
 
                   --  Second case is where we have a constant whose
-                  --  definition is of the form of an adress as in:
+                  --  definition is of the form of an address as in:
 
                   --     A : constant Address := K'Address;
                   --     ...
Index: ada/sysdep.c
===================================================================
--- ada/sysdep.c	(revision 114167)
+++ ada/sysdep.c	(working copy)
@@ -187,7 +187,7 @@ __gnat_ttyname (int filedes)
     return NULL;
 }
 
-/* This function is needed to fix a bug under Win95/98. Under these plateforms
+/* This function is needed to fix a bug under Win95/98. Under these platforms
    doing :
                 ch1 = getch();
 		ch2 = fgetc (stdin);
Index: ada/targtyps.c
===================================================================
--- ada/targtyps.c	(revision 114167)
+++ ada/targtyps.c	(working copy)
@@ -89,7 +89,7 @@ get_target_char_size (void)
 Pos
 get_target_wchar_t_size (void)
 {
-  /* We never want wide chacters less than "short" in Ada.  */
+  /* We never want wide characters less than "short" in Ada.  */
   return MAX (SHORT_TYPE_SIZE, WCHAR_TYPE_SIZE);
 }
 
Index: ada/tb-alvxw.c
===================================================================
--- ada/tb-alvxw.c	(revision 114167)
+++ ada/tb-alvxw.c	(working copy)
@@ -630,7 +630,7 @@ find_proc_desc (CORE_ADDR pc,
 {
   CORE_ADDR startaddr;
 
-  /* If heuristic_fence_post is non-zero, determine the procedure
+  /* If heuristic_fence_post is nonzero, determine the procedure
      start address by examining the instructions.
      This allows us to find the start address of static functions which
      have no symbolic information, as startaddr would have been set to
Index: ada/tracebak.c
===================================================================
--- ada/tracebak.c	(revision 114167)
+++ ada/tracebak.c	(working copy)
@@ -35,7 +35,7 @@
    It has been tested on the following configurations:
    PowerPC/AiX
    PowerPC/VxWorks
-   Sparc/Solaris
+   SPARC/Solaris
    i386/GNU/Linux
    i386/Solaris
    i386/NT
@@ -187,7 +187,7 @@ extern void (*Unlock_Task) (void);
 
    o FETCH_UP_FRAME, to force an invocation of __builtin_frame_address with a
      positive argument right after a possibly forced call even if FRAME_LEVEL
-     is 0. See the Sparc Solaris case for an example where this is useful.
+     is 0. See the SPARC Solaris case for an example where this is useful.
 
   */
 
Index: ada/trans.c
===================================================================
--- ada/trans.c	(revision 114167)
+++ ada/trans.c	(working copy)
@@ -1510,7 +1510,7 @@ Subprogram_Body_to_gnu (Node_Id gnat_nod
      we must turn a condition into the corresponding exception even if there
      is no applicable Ada handler, and need at least one condition handler per
      possible call chain involving GNAT code.  OTOH, establishing the handler
-     has a cost so we want to mimize the number of subprograms into which this
+     has a cost so we want to minimize the number of subprograms into which this
      happens.  The foreign or exported condition is expected to satisfy all
      the constraints.  */
   if (TARGET_ABI_OPEN_VMS
@@ -4829,7 +4829,7 @@ gnat_gimplify_stmt (tree *stmt_p)
 /* The reason for this routine's existence is two-fold.
    First, with some debugging formats, notably MDEBUG on SGI
    IRIX, the linker will remove duplicate debugging information if two
-   clients have identical debugguing information.  With the normal scheme
+   clients have identical debugging information.  With the normal scheme
    of elaboration, this does not usually occur, since entities in with'ed
    packages are elaborated on demand, and if clients have different usage
    patterns, the normal case, then the order and selection of entities
Index: ada/utils.c
===================================================================
--- ada/utils.c	(revision 114167)
+++ ada/utils.c	(working copy)
@@ -186,7 +186,7 @@ present_gnu_tree (Entity_Id gnat_entity)
 }
 
 
-/* Return non-zero if we are currently in the global binding level.  */
+/* Return nonzero if we are currently in the global binding level.  */
 
 int
 global_bindings_p (void)
@@ -2874,7 +2874,7 @@ convert (tree type, tree expr)
     case VIEW_CONVERT_EXPR:
       {
 	/* GCC 4.x is very sensitive to type consistency overall, and view
-	   conversions thus are very frequent.  Eventhough just "convert"ing
+	   conversions thus are very frequent.  Even though just "convert"ing
 	   the inner operand to the output type is fine in most cases, it
 	   might expose unexpected input/output type mismatches in special
 	   circumstances so we avoid such recursive calls when we can.  */
@@ -2882,7 +2882,7 @@ convert (tree type, tree expr)
 	tree op0 = TREE_OPERAND (expr, 0);
 
 	/* If we are converting back to the original type, we can just
-	   lift the input conversion.  This is a common occurence with
+	   lift the input conversion.  This is a common occurrence with
 	   switches back-and-forth amongst type variants.  */
 	if (type == TREE_TYPE (op0))
 	  return op0;


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: ada/gigi.h
===================================================================
--- ada/gigi.h	(revision 114167)
+++ ada/gigi.h	(working copy)
@@ -63,7 +63,7 @@ extern void init_dummy_type (void);
    DEFINITION is nonzero if this call is intended for a definition.  This is
    used for separate compilation where it necessary to know whether an
    external declaration or a definition should be created if the GCC equivalent
-   was not created previously.  The value of 1 is normally used for a non-zero
+   was not created previously.  The value of 1 is normally used for a nonzero
    DEFINITION, but a value of 2 is used in special circumstances, defined in
    the code.  */
 extern tree gnat_to_gnu_entity (Entity_Id gnat_entity, tree gnu_expr,
@@ -406,7 +406,7 @@ extern GTY(()) tree static_dtors;
 /* Routines expected by the gcc back-end. They must have exactly the same
    prototype and names as below.  */
 
 /* Returns non-zero if we are currently in the global binding level       */
 extern int global_bindings_p (void);
 
 /* Enter and exit a new binding level. */
@@ -406,7 +406,7 @@ extern GTY(()) tree static_dtors;
    prototype and names as below.  */
 
-/* Returns non-zero if we are currently in the global binding level       */
+/* Returns nonzero if we are currently in the global binding level.  */
 extern int global_bindings_p (void);
 